@@ -97,7 +97,7 @@ static QByteArray join(char sep, const QCStringList &list)
         return QByteArray();
     }
     QByteArray result = list.front();
-    for (QCStringList::const_iterator it = ++list.begin(); it != list.end(); ++it) {
+    for (QCStringList::const_iterator it = ++list.begin(), end(list.end()); it != end; ++it) {
         result += sep + *it;
     }
     return result;
